Out

Struct Out 

pub struct Out<'a, T: ?Sized> { /* private fields */ }
Wrapper for write-only “out pointers” that are safe to write to

Implementations

Source

impl<'a, T: ?Sized> Out<'a, T>

pub unsafe fn nullable(ptr: *mut T) -> Option<Self>

Safety
  • pointer must either be NULL, or be valid for the duration of lifetime 'a
pub unsafe fn nonnull(ptr: *mut T) -> Self

Safety
  • pointer must be valid for the duration of lifetime 'a
pub fn from_mut(r: &'a mut T) -> Self

pub fn as_mut_ptr(&mut self) -> *mut T

Source

impl<'a, T> Out<'a, T>

pub fn from_uninit_mut(r: &'a mut MaybeUninit<T>) -> Self

pub fn write(&mut self, t: T)

Source

impl<'a, T, const N: usize> Out<'a, [T; N]>

pub fn as_slice_mut<'b>(&'b mut self) -> Out<'b, [T]>

Source

impl<'a, T> Out<'a, [T]>

pub unsafe fn from_raw_parts(ptr: *mut T, len: usize) -> Self

Safety

If len > 0, ptr be valid for len elements of T, during lifetime 'a.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn split_at_checked<'b>(&'b mut self, n: usize) -> Option<[Out<'b, [T]>; 2]>

pub fn copy_from_slice(&mut self, src: &[T])
where T: Copy,

pub fn copy_common_length_from_slice(&mut self, src: &[T]) -> usize
where T: Copy,

pub fn subslice<'b>(&'b mut self, start: usize, end: usize) -> Out<'b, [T]>

pub fn index<'b>(&'b mut self, i: usize) -> Out<'b, T>

Source

impl<T: Plain> Out<'_, [T]>

pub fn zero(&mut self)

pub fn cast_slice_to<'b, U>(self) -> Out<'b, [U]>
where T: CastSlice<U>,

Source

impl<'a, T: ?Sized> Out<'a, T>

pub unsafe fn with_lifetime_of<'b, U: ?Sized>(self, u: &'b U) -> Out<'b, T>