pub unsafe trait OutProject { }Expand description
Marker trait for types where it is sound to turn Out<struct { ... }> into struct { ...: Out<...> } by simply referencing fields. This is safe for any struct but must not be
implemented for Deref types so that Out<&struct { ... }> is never projected in a way that
adds mutability.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".